@@ -1,8 +1,7 @@
 from .file_filters import *
-from .filter_params import *
 from .map_utils import *
-from .pdf_utils import *
-from .file_reader import *
+from .reader_utils import *
 from .find_collect import *
+from .find_content import *
 from .initFunctionsGen import call_for_all_tabs,get_for_all_tabs
 
