@@ -41,6 +41,6 @@ def extract_class(path: str):
             funcs.append(m.group(1))
     return funcs
 def get_all_py_file_paths(*args,**kwargs):
-    globs = collect_globs(args,allowed_exts='.py',**kwargs)
+    globs = collect_globs(*args,allowed_exts='.py',**kwargs)
     globs = [glo for glo in globs.get('files') if glo]
     return globs
